@@ -1,3 +1,4 @@
+use std::borrow::Cow;
 use crate::dom::RefFn;
 
 pub use crate::animation::AnimatedSignalVec;
@@ -85,6 +86,18 @@ impl<'a> AsStr for &'a str {
     }
 }
 
+impl<'a> AsStr for Cow<'a, str> {
+    #[inline]
+    fn as_str(&self) -> &str {
+        &*self
+    }
+
+    #[inline]
+    fn with_str<A, F>(&self, f: F) -> A where F: FnOnce(&str) -> A {
+        f(&*self)
+    }
+}
+
 impl<A, C> AsStr for RefFn<A, str, C> where C: Fn(&A) -> &str {
     #[inline]
     fn as_str(&self) -> &str {
